%define anolis_release 1
%bcond_without golist

%global forgeurl  https://pagure.io/go-rpm-macros

%global _spectemplatedir %{_datadir}/rpmdevtools/anolis
%global _docdir_fmt     %{name}
 
# Master definition that will be written to macro files
%global golang_arches_future x86_64 aarch64
%global golang_arches   %{golang_arches_future}
# Go sources can contain arch-specific files and our macros will package the
# correct files for each architecture. Therefore, move gopath to _libdir and
# make Go devel packages archful
%global gopath          %{_datadir}/gocode
 
Name:      go-rpm-macros
Version:   3.2.0
Release:   %{anolis_release}%{?dist}
Summary:   Build-stage rpm automation for Go packages
 
License:   GPL-3.0-or-later
URL:       %{forgeurl}
Source:    https://pagure.io/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

Patch1:    0001-modify-for-anolis.patch

Requires:  go-srpm-macros = %{version}-%{release}
Requires:  go-filesystem  = %{version}-%{release}
%if %{with golist}
Requires:  golist
%endif

%ifarch %{golang_arches}
Requires:  golang
Provides:  compiler(golang)
Provides:  compiler(go-compiler) = 2
Obsoletes: go-compilers-golang-compiler < %{version}-%{release}
%endif
 
%description
This package provides build-stage rpm automation to simplify the creation of Go
language (golang) packages.
 
It does not need to be included in the default build root: go-srpm-macros will
pull it in for Go packages only.
 
%package -n go-srpm-macros
Summary:   Source-stage rpm automation for Go packages
BuildArch: noarch
Requires:  system-rpm-config
 
%description -n go-srpm-macros
This package provides SRPM-stage rpm automation to simplify the creation of Go
language (golang) packages.
 
It limits itself to the automation subset required to create Go SRPM packages
and needs to be included in the default build root.
 
The rest of the automation is provided by the go-rpm-macros package, that
go-srpm-macros will pull in for Go packages only.
 
%package -n go-filesystem
Summary:   Directories used by Go packages
License:   LicenseRef-Fedora-Public-Domain
 
%description -n go-filesystem
This package contains the basic directory layout used by Go packages.
 
%package -n go-rpm-templates
Summary:   RPM spec templates for Go packages
License:   MIT
# go-rpm-macros only exists on some architectures, so this package cannot be noarch
Requires:  go-rpm-macros = %{version}-%{release}
#https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/51
#Requires:  redhat-rpm-templates
 
%description -n go-rpm-templates
This package contains documented rpm spec templates showcasing how to use the
macros provided by go-rpm-macros to create Go packages.
 
%prep
%autosetup -n %{name}-%{version} -p1
%writevars -f rpm/macros.d/macros.go-srpm golang_arches golang_arches_future gopath
for template in templates/rpm/*\.spec ; do
  target=$(echo "${template}" | sed "s|^\(.*\)\.spec$|\1-bare.spec|g")
  grep -v '^#' "${template}" > "${target}"
  touch -r "${template}" "${target}"
done
 
%install
install -m 0755 -vd   %{buildroot}%{rpmmacrodir}
 
install -m 0755 -vd   %{buildroot}%{_rpmluadir}/anolis/srpm
install -m 0644 -vp   rpm/lua/srpm/*lua \
                      %{buildroot}%{_rpmluadir}/anolis/srpm
 
install -m 0755 -vd   %{buildroot}%{gopath}/src
 
install -m 0755 -vd   %{buildroot}%{_spectemplatedir}
 
install -m 0644 -vp   templates/rpm/*spec \
                      %{buildroot}%{_spectemplatedir}
 
install -m 0755 -vd   %{buildroot}%{_bindir}
install -m 0755 bin/* %{buildroot}%{_bindir}
 
install -m 0644 -vp   rpm/macros.d/macros.go-*rpm* \
                      %{buildroot}%{rpmmacrodir}
install -m 0755 -vd   %{buildroot}%{_rpmluadir}/anolis/rpm
install -m 0644 -vp   rpm/lua/rpm/*lua \
                      %{buildroot}%{_rpmluadir}/anolis/rpm
install -m 0755 -vd   %{buildroot}%{_rpmconfigdir}/fileattrs
install -m 0644 -vp   rpm/fileattrs/*.attr \
                      %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0755 -vp   rpm/*\.{prov,deps} \
                      %{buildroot}%{_rpmconfigdir}/

%ifarch %{golang_arches}
install -m 0644 -vp   rpm/macros.d/macros.go-compilers-golang{,-pie} \
                      %{buildroot}%{_rpmconfigdir}/macros.d/
%endif

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/*
%{_rpmconfigdir}/fileattrs/*.attr
%{_rpmconfigdir}/*.prov
%{_rpmconfigdir}/*.deps
%{_rpmmacrodir}/macros.go-rpm*
%{_rpmmacrodir}/macros.go-compiler*
%{_rpmluadir}/anolis/rpm/*.lua
 
%files -n go-rpm-templates
%license LICENSE-templates.txt
%doc README.md
# https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/51
%dir %{dirname:%{_spectemplatedir}}
%dir %{_spectemplatedir}
%{_spectemplatedir}/*.spec
 
%files -n go-filesystem
%dir %{gopath}
%dir %{gopath}/src
 
# we only build go-srpm-macros on all architectures
%files -n go-srpm-macros
%license LICENSE.txt
%doc README.md
%{_rpmmacrodir}/macros.go-srpm
%{_rpmluadir}/anolis/srpm/*.lua
 
 
%changelog
* Mon Aug 21 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.2.0-1
- update version to 3.2.0

* Wed Apr 12 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 3.0.15-3
- Refact spec

* Fri Mar 31 2023 happy_orange <songnannan@linux.alibaba.com> - 3.0.15-2
- remove golist in requires

* Thu Mar 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> 3.0.15-1
- init from upstream 3.0.15.
